==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/chest/dialogs_pl.lua <==

dialogId("tru-v-nasly", "font_big", "So we have finally found it.")
dialogStr("W końcu go znaleźliśmy.")


dialogId("tru-m-co", "font_small", "What?")
dialogStr("Co mianowicie?")


dialogId("tru-v-poklad", "font_big", "Captain Silver`s treasure, of course.")
dialogStr("Skarb kapitana Silvera.")


dialogId("tru-v-gral", "font_big", "The Holy Grail, of course.")
dialogStr("Świętego Graala, oczywiście.")


dialogId("tru-v-vkupe", "font_big", "It`s neatly in one place: the treasure and the Grail.")
dialogStr("Wszystko na swoim miejscu: skarb i Graal.")


dialogId("tru-m-zrada", "font_small", "I think it`s much too easy to be true.")
dialogStr("Coś mi się wydaje, że to zbyt piękne, by było prawdziwe.")


dialogId("tru-m-oznamit", "font_small", "I think that if it really was our goal, the game would let the player know.")
dialogStr("Wydaje mi się, że gdyby to rzeczywiście był cel naszych poszukiwań, gra powiadomiłaby gracza.")


dialogId("tru-v-stacit", "font_big", "But I have let them know. That could be enough.")
dialogStr("No przecież go powiadomiłem. To nie wystarczy?")


dialogId("tru-m-zpochybnit", "font_small", "But I have casted doubts on it. This could confuse them.")
dialogStr("Ale ja zasiałam wątpliwości. To go mogło skonfudować.")


dialogId("tru-v-nejspis", "font_big", "Well, all right. PROBABLY this is not what we are looking for.")
dialogStr("Dobra, niech ci będzie. To PRAWDOPODOBNIE nie jest to, czego szukamy.")


dialogId("tru-m-nejistota", "font_small", "That's better. There remains a bit of uncertainty.")
dialogStr("Tak lepiej. Wciąż pozostaje nieco nadziei.")


dialogId("tru-m-truhla0", "font_small", "Couldn`t we close that chest?")
dialogStr("Może zamknijmy ten kufer?")


dialogId("tru-m-truhla1", "font_small", "What if we try to close that chest?")
dialogStr("A może zamkniemy ten kufer?")


dialogId("tru-v-truhla0", "font_big", "It would be much easier with the chest closed.")
dialogStr("Byłoby dużo prościej, gdyby ten kufer był zamknięty.")


dialogId("tru-v-truhla1", "font_big", "Try to push its lid.")
dialogStr("Spróbuj popchnąć wieko.")


dialogId("tru-m-vzit0", "font_small", "Won`t we take something with us?")
dialogStr("Może weźmiemy ze sobą parę drobiazgów?")


dialogId("tru-m-vzit1", "font_small", "What about taking some treasure with us?")
dialogStr("Bierzemy ze sobą ten skarb?")


dialogId("tru-m-vzit2", "font_small", "Aren`t you sorry to leave all this treasure behind?")
dialogStr("Nie szkoda ci zostawiać tu tego skarbu?")


dialogId("tru-v-vzit0", "font_big", "We will be glad if we manage to get out ourselves.")
dialogStr("Będzie dobrze, jeśli sami stąd wyjdziemy.")


dialogId("tru-v-vzit1", "font_big", "Don`t forget our mission.")
dialogStr("Nie zapomnij o naszej misji.")


dialogId("tru-v-vzit2", "font_big", "The treasure would only hinder us.")
dialogStr("Ten skarb by nam tylko zawadzał.")


dialogId("tru-v-zrak", "font_big", "All this glinting is a sight for the eyes.")
dialogStr("Aż miło patrzeć na te wszystkie błyskotki.")


dialogId("tru-m-trpyt", "font_small", "Everything here gleams so. It makes me dizzy.")
dialogStr("Wszystko tu błyszczy, w głowie mi się od tego kręci.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/chest/dialogs_pl.lua <==

dialogId("tru-v-nasly", "font_big", "So we have finally found it.")
dialogStr("W końcu go znaleźliśmy.")


dialogId("tru-m-co", "font_small", "What?")
dialogStr("Co mianowicie?")


dialogId("tru-v-poklad", "font_big", "Captain Silver’s treasure, of course.")
dialogStr("Skarb kapitana Silvera.")


dialogId("tru-v-gral", "font_big", "The Holy Grail, of course.")
dialogStr("Świętego Graala, oczywiście.")


dialogId("tru-v-vkupe", "font_big", "It’s neatly in one place: the treasure and the Grail.")
dialogStr("Wszystko na swoim miejscu: skarb i Graal.")


dialogId("tru-m-zrada", "font_small", "I think it’s much too easy to be true.")
dialogStr("Coś mi się wydaje, że to zbyt piękne, by było prawdziwe.")


dialogId("tru-m-oznamit", "font_small", "I think that if it really was our goal, the game would let the player know.")
dialogStr("Wydaje mi się, że gdyby to rzeczywiście był cel naszych poszukiwań, gra powiadomiłaby gracza.")


dialogId("tru-v-stacit", "font_big", "But I have let them know. That could be enough.")
dialogStr("No przecież go powiadomiłem. To nie wystarczy?")


dialogId("tru-m-zpochybnit", "font_small", "But I have casted doubts on it. This could confuse them.")
dialogStr("Ale ja zasiałam wątpliwości. To go mogło skonfudować.")


dialogId("tru-v-nejspis", "font_big", "Well, all right. PROBABLY this is not what we are looking for.")
dialogStr("Dobra, niech ci będzie. To PRAWDOPODOBNIE nie jest to, czego szukamy.")


dialogId("tru-m-nejistota", "font_small", "That's better. There remains a bit of uncertainty.")
dialogStr("Tak lepiej. Wciąż pozostaje nieco nadziei.")


dialogId("tru-m-truhla0", "font_small", "Couldn’t we close that chest?")
dialogStr("Może zamknijmy ten kufer?")


dialogId("tru-m-truhla1", "font_small", "What if we try to close that chest?")
dialogStr("A może zamkniemy ten kufer?")


dialogId("tru-v-truhla0", "font_big", "It would be much easier with the chest closed.")
dialogStr("Byłoby dużo prościej, gdyby ten kufer był zamknięty.")


dialogId("tru-v-truhla1", "font_big", "Try to push its lid.")
dialogStr("Spróbuj popchnąć wieko.")


dialogId("tru-m-vzit0", "font_small", "Won’t we take something with us?")
dialogStr("Może weźmiemy ze sobą parę drobiazgów?")


dialogId("tru-m-vzit1", "font_small", "What about taking some treasure with us?")
dialogStr("Bierzemy ze sobą ten skarb?")


dialogId("tru-m-vzit2", "font_small", "Aren’t you sorry to leave all this treasure behind?")
dialogStr("Nie szkoda ci zostawiać tu tego skarbu?")


dialogId("tru-v-vzit0", "font_big", "We will be glad if we manage to get out ourselves.")
dialogStr("Będzie dobrze, jeśli sami stąd wyjdziemy.")


dialogId("tru-v-vzit1", "font_big", "Don’t forget our mission.")
dialogStr("Nie zapomnij o naszej misji.")


dialogId("tru-v-vzit2", "font_big", "The treasure would only hinder us.")
dialogStr("Ten skarb by nam tylko zawadzał.")


dialogId("tru-v-zrak", "font_big", "All this glinting is a sight for the eyes.")
dialogStr("Aż miło patrzeć na te wszystkie błyskotki.")


dialogId("tru-m-trpyt", "font_small", "Everything here gleams so. It makes me dizzy.")
dialogStr("Wszystko tu błyszczy, w głowie mi się od tego kręci.")
